CurlParser class

A utility class to parse curl commands into CurlRequest objects.

Parse all params https://gist.github.com/eneko/dc2d8edd9a4b25c5b0725dd123f98b10

Constructors

CurlParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String curlCommand) CurlRequest
Parse a curl command string into a CurlRequest object.