CurlRequest class
Class to represent a parsed curl request with all its options and parameters.
Constructors
Properties
- anyauth ↔ bool
-
Whether to use any suitable authentication method (--anyauth)
getter/setter pair
- append ↔ bool
-
Whether to append to the target file (-a/--append)
getter/setter pair
- auth ↔ String
-
Authentication credentials in format 'username:password'
getter/setter pair
- basic ↔ bool
-
Whether to use HTTP Basic authentication (--basic)
getter/setter pair
- caCert ↔ String?
-
Path to CA certificate file (--cacert)
getter/setter pair
- cert ↔ String?
-
Path to client certificate file (-E/--cert)
getter/setter pair
- ciphers ↔ String?
-
SSL ciphers to use (--ciphers)
getter/setter pair
- compressed ↔ bool
-
Whether to request compressed response (--compressed)
getter/setter pair
- connectTimeout ↔ int?
-
Connection timeout in seconds (--connect-timeout)
getter/setter pair
-
Path to file where cookies should be stored
getter/setter pair
-
Cookies to be sent with the request
getter/setter pair
- data ↔ String
-
Request body data as string
getter/setter pair
- dataFromFile ↔ String
-
Path to file containing request data (from @file syntax)
getter/setter pair
- digest ↔ bool
-
Whether to use HTTP Digest authentication (--digest)
getter/setter pair
- fail ↔ bool
-
Whether to fail silently on HTTP errors (-f/--fail)
getter/setter pair
- followRedirects ↔ bool
-
Whether to follow redirects (-L/--location)
getter/setter pair
-
formData
↔ List<
String> -
List of form data entries for multipart/form-data requests
getter/setter pair
- ftpAccount ↔ String?
-
FTP account data (--ftp-account)
getter/setter pair
- ftpCreateDirs ↔ bool
-
Whether to create remote directories if they don't exist (--ftp-create-dirs)
getter/setter pair
- ftpMethod ↔ String?
-
FTP method to use for transactions (--ftp-method)
getter/setter pair
- ftpPasv ↔ bool
-
Whether to use passive mode for FTP (--ftp-pasv)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- head ↔ bool
-
Whether to use a HEAD request (-I/--head)
getter/setter pair
-
headers
↔ Map<
String, String> -
Map of HTTP headers
getter/setter pair
- http09 ↔ bool
-
Whether to allow HTTP/0.9 responses (--http0.9)
getter/setter pair
- http10 ↔ bool
-
Whether to use HTTP/1.0 (-0/--http1.0)
getter/setter pair
- http11 ↔ bool
-
Whether to use HTTP/1.1 (--http1.1)
getter/setter pair
- http2 ↔ bool
-
Whether to use HTTP/2 (--http2)
getter/setter pair
- insecure ↔ bool
-
Whether to skip SSL certificate validation (-k/--insecure)
getter/setter pair
- interface ↔ String?
-
Network interface to use (--interface)
getter/setter pair
- ipv4Only ↔ bool
-
Whether to use only IPv4 (-4/--ipv4)
getter/setter pair
- ipv6Only ↔ bool
-
Whether to use only IPv6 (-6/--ipv6)
getter/setter pair
- key ↔ String?
-
Path to private key file (--key)
getter/setter pair
- keyType ↔ String?
-
Type of private key (--key-type)
getter/setter pair
- maxRedirs ↔ int?
-
Maximum number of redirects to follow (--max-redirs)
getter/setter pair
- maxTime ↔ int?
-
Maximum time allowed for the transfer (-m/--max-time)
getter/setter pair
- method ↔ String
-
The HTTP method (GET, POST, PUT, etc.)
getter/setter pair
- negotiate ↔ bool
-
Whether to use HTTP Negotiate/SPNEGO authentication (--negotiate)
getter/setter pair
- noBuffer ↔ bool
-
Whether to disable buffering of the output stream (-N/--no-buffer)
getter/setter pair
- ntlm ↔ bool
-
Whether to use NTLM authentication (--ntlm)
getter/setter pair
- oauth2Bearer ↔ String?
-
OAuth 2.0 Bearer Token (--oauth2-bearer)
getter/setter pair
- outputFile ↔ String
-
Path to output file (-o/--output)
getter/setter pair
- proxy ↔ String
-
Proxy to use (-x/--proxy)
getter/setter pair
- proxyAuth ↔ String
-
Proxy authentication credentials (-U/--proxy-user)
getter/setter pair
- proxyInsecure ↔ bool
-
Whether to skip proxy SSL certificate validation (--proxy-insecure)
getter/setter pair
- proxytunnel ↔ bool
-
Whether to tunnel through HTTP proxy (-p/--proxytunnel)
getter/setter pair
- queryParameters ↔ String
-
Query parameters as a string
getter/setter pair
- range ↔ String
-
Range request value (-r/--range)
getter/setter pair
- referer ↔ String
-
Referer URL (-e/--referer)
getter/setter pair
- remoteTime ↔ bool
-
Whether to set the remote file's time on the local output (-R/--remote-time)
getter/setter pair
-
resolveHosts
↔ List<
String> -
List of host:port:address mappings for DNS resolution (--resolve)
getter/setter pair
- retryCount ↔ int?
-
Number of retry attempts for transient errors (--retry)
getter/setter pair
- retryDelay ↔ int?
-
Delay between retries in seconds (--retry-delay)
getter/setter pair
- retryMaxTime ↔ int?
-
Maximum time in seconds for retries (--retry-max-time)
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- silent ↔ bool
-
Whether to use silent mode (-s/--silent)
getter/setter pair
- sslv2 ↔ bool?
-
Whether to use SSLv2 (-2/--sslv2)
getter/setter pair
- sslv3 ↔ bool?
-
Whether to use SSLv3 (-3/--sslv3)
getter/setter pair
- tlsMax ↔ String?
-
Maximum TLS version to use (--tls-max)
getter/setter pair
- tlsv1 ↔ bool?
-
Whether to use TLSv1 (-1/--tlsv1)
getter/setter pair
- tlsv10 ↔ bool?
-
Whether to use TLSv1.0 (--tlsv1.0)
getter/setter pair
- tlsv11 ↔ bool?
-
Whether to use TLSv1.1 (--tlsv1.1)
getter/setter pair
- tlsv12 ↔ bool?
-
Whether to use TLSv1.2 (--tlsv1.2)
getter/setter pair
- tlsv13 ↔ bool?
-
Whether to use TLSv1.3 (--tlsv1.3)
getter/setter pair
- uploadFile ↔ String
-
Path to file to upload (-T/--upload-file)
getter/setter pair
- url ↔ String
-
The target URL for the request
getter/setter pair
- verbose ↔ bool
-
Whether to use verbose output (-v/--verbose)
getter/setter pair
- writeOut ↔ String
-
Write-out format string (-w/--write-out)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDartHttpRequest(
) → String - Generate a Dart http package request code
-
toJson(
) → String - Convert the request to a JSON string
-
toMap(
) → Map< String, dynamic> - Convert the request to a map representation
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited